import type { TourStep, TourConfig, TourOptions, TourInstance, TourConstructor } from './types';
import { createElement, getStaticSide, isElementInViewport } from './utils';
import "./style.less";
/**
 * Tour 类 - 用于创建页面引导流程
 * @class Tour
 */
export declare class Tour implements TourInstance {
    /** 当前高亮的目标元素 */
    private targetElement?;
    /** tooltip 元素 */
    private tooltipElement?;
    /** tooltip 的箭头元素 */
    private arrowElement?;
    /** 位置更新清理函数 */
    private positionCleanup?;
    /** 当前步骤索引 */
    private currentStep;
    /** 引导步骤配置 */
    private steps;
    /** 实例配置 */
    private instanceConfig?;
    /** Tour 的全局配置 */
    private static config;
    constructor(options: TourOptions | TourStep[]);
    /**
     * 获取合并后的最终配置
     * @private
     * @returns {TourConfig} 最终配置
     */
    private getConfig;
    /**
     * 检查当前步骤的目标元素是否存在
     * @private
     * @returns {HTMLElement | null} 目标元素或 null
     */
    private checkTargetElement;
    /**
     * 初始化当前步骤
     * @description
     * 1. 清理上一步的位置更新监听
     * 2. 检查目标元素是否存在
     * 3. 移除上一个目标元素的高亮样式
     * 4. 隐藏 tooltip
     * 5. 检查目标元素是否在视口内，决定是否需要滚动
     * @private
     */
    private initStep;
    /**
     * 显示 tooltip
     * @description
     * 1. 高亮目标元素
     * 2. 更新 tooltip 内容
     * 3. 启动位置自动更新
     * 4. 显示 tooltip
     * @private
     */
    private showTooltip;
    /**
     * 清理引导相关的所有内容
     * @description
     * 1. 移除 tooltip 元素
     * 2. 清理位置更新监听
     * 3. 移除目标元素的高亮样式
     * 4. 重置当前步骤
     * @public
     */
    cleanup(): void;
    /**
     * 更新 tooltip 的位置
     * @description
     * 1. 计算 tooltip 相对于目标元素的位置
     * 2. 应用偏移、翻转、移位等中间件
     * 3. 更新 tooltip 和箭头的位置
     * @private
     * @returns {() => void} 位置更新函数
     */
    private updatePosition;
    /**
     * 创建 tooltip 相关的 DOM 元素
     * @description
     * 1. 创建 tooltip 容器元素
     * 2. 创建箭头元素
     * 3. 创建内容区域
     * 4. 创建按钮组
     * 5. 将所有元素添加到文档中
     * @private
     */
    private createTooltipElements;
    /**
     * 更新 tooltip 的内容和按钮
     * @description
     * 1. 更新内容区域的文本
     * 2. 重新创建按钮组
     * @private
     */
    private updateTooltipContent;
    /**
     * 创建操作按钮
     * @description
     * 1. 创建上一步按钮（如果不是第一步）
     * 2. 创建下一步/完成按钮
     * 3. 创建跳过按钮（如果不是最后一步）
     * 4. 绑定按钮点击事件
     * @private
     * @returns {HTMLElement[]} 按钮元素数组
     */
    private createButtons;
    /**
     * 进入下一步
     * @public
     */
    next(): void;
    /**
     * 返回上一步
     * @public
     */
    previous(): void;
    /**
     * 跳过引导
     * @public
     */
    skip(): void;
    /**
     * 配置 Tour 的全局设置
     * @static
     * @param {Partial<typeof Tour.config>} options - 配置选项
     */
    static configure(options: Partial<typeof Tour.config>): void;
    goTo(index: number): void;
    getCurrentStep(): number;
    getTotalSteps(): number;
    isFirst(): boolean;
    isLast(): boolean;
    /**
     * 开始执行引导
     * @public
     */
    run(): void;
}
export type { TourStep, TourConfig, TourOptions, TourInstance, TourConstructor };
export { createElement, getStaticSide, isElementInViewport };
